@@ -6,6 +6,8 @@ import numpy as np
 import pandas as pd
 
 from fedot.core.adapter import DirectAdapter, register_native
+from fedot.core.dag.graph_utils import ordered_subnodes_hierarchy
+from fedot.core.dag.convert import graph_structure_as_nx_graph
 from fedot.core.dag.verification_rules import has_no_cycle, has_no_self_cycled_nodes
 from fedot.core.log import default_log
 from fedot.core.optimisers.gp_comp.gp_optimizer import EvoGraphOptimizer
@@ -17,7 +19,6 @@ from fedot.core.optimisers.gp_comp.pipeline_composer_requirements import Pipelin
 from fedot.core.optimisers.graph import OptGraph, OptNode
 from fedot.core.optimisers.objective import Objective, ObjectiveEvaluate
 from fedot.core.optimisers.optimizer import GraphGenerationParams
-from fedot.core.pipelines.convert import graph_structure_as_nx_graph
 from fedot.core.utils import fedot_project_root
 
 random.seed(1)
@@ -59,9 +60,9 @@ def custom_mutation(graph: OptGraph, **kwargs):
             random_node = graph.nodes[rid]
             other_random_node = graph.nodes[random.choice(range(len(graph.nodes)))]
             nodes_not_cycling = (random_node.descriptive_id not in
-                                 [n.descriptive_id for n in other_random_node.ordered_subnodes_hierarchy()] and
+                                 [n.descriptive_id for n in ordered_subnodes_hierarchy(other_random_node)] and
                                  other_random_node.descriptive_id not in
-                                 [n.descriptive_id for n in random_node.ordered_subnodes_hierarchy()])
+                                 [n.descriptive_id for n in ordered_subnodes_hierarchy(random_node)])
             if nodes_not_cycling:
                 graph.connect_nodes(random_node, other_random_node)
     except Exception as ex:
@@ -102,7 +103,7 @@ def run_custom_example(timeout: datetime.timedelta = None):
         adapter=DirectAdapter(base_graph_class=CustomGraphModel, base_node_class=CustomGraphNode),
         rules_for_constraint=rules)
 
-    objective = Objective([custom_metric])
+    objective = Objective({'custom': custom_metric})
     optimiser = EvoGraphOptimizer(
         graph_generation_params=graph_generation_params,
         objective=objective,
