@@ -1,9 +1,10 @@
 import pandas as pd
+
 from fedot.api.main import Fedot
 from fedot.core.utils import fedot_project_root
 
 
-def run_classification_multiobj_example(with_plot=True, timeout=None):
+def run_classification_multiobj_example(visualization=False, timeout=1):
     train_data = pd.read_csv(f'{fedot_project_root()}/examples/data/Hill_Valley_with_noise_Training.data')
     test_data = pd.read_csv(f'{fedot_project_root()}/examples/data/Hill_Valley_with_noise_Testing.data')
     target = test_data['class']
@@ -17,12 +18,13 @@ def run_classification_multiobj_example(with_plot=True, timeout=None):
     auto_model.fit(features=train_data, target='class')
     prediction = auto_model.predict_proba(features=test_data)
     print(auto_model.get_metrics(target))
-    auto_model.plot_prediction()
-    if with_plot:
+
+    if visualization:
+        auto_model.plot_prediction()
         auto_model.plot_pareto()
 
     return prediction
 
 
 if __name__ == '__main__':
-    run_classification_multiobj_example()
+    run_classification_multiobj_example(visualization=True)
