@@ -2,9 +2,8 @@ from fedot.api.main import Fedot
 from fedot.core.utils import fedot_project_root
 
 
-def run_classification_example(timeout: float = None):
+def run_classification_example(timeout: float = None, visualization=False):
     problem = 'classification'
-
     train_data_path = f'{fedot_project_root()}/cases/data/scoring/scoring_train.csv'
     test_data_path = f'{fedot_project_root()}/cases/data/scoring/scoring_test.csv'
 
@@ -19,9 +18,10 @@ def run_classification_example(timeout: float = None):
     auto_model.fit(features=train_data_path, target='target')
     prediction = auto_model.predict_proba(features=test_data_path)
     print(auto_model.get_metrics())
-    auto_model.plot_prediction()
+    if visualization:
+        auto_model.plot_prediction()
     return prediction
 
 
 if __name__ == '__main__':
-    run_classification_example(timeout=10.0)
+    run_classification_example(timeout=10.0, visualization=True)
