@@ -4,7 +4,7 @@ from fedot.api.main import Fedot
 from fedot.core.utils import fedot_project_root
 
 
-def run_api_explain_example(visualize=True, timeout=None):
+def run_api_explain_example(visualization=False, timeout=None):
     train_data = pd.read_csv(f'{fedot_project_root()}/cases/data/cancer/cancer_train.csv', index_col=0)
     figure_path = 'api_explain_example.png'
 
@@ -20,7 +20,8 @@ def run_api_explain_example(visualize=True, timeout=None):
 
     # Current pipeline explaining
     explainer = model.explain(
-        method='surrogate_dt', visualize=visualize,  # The following parameters are only used if visualize == True:
+        method='surrogate_dt', visualization=visualization,
+        # The following parameters are only used if visualize == True:
         save_path=figure_path, dpi=200, feature_names=feature_names,
         class_names=class_names,
         precision=6
@@ -30,4 +31,4 @@ def run_api_explain_example(visualize=True, timeout=None):
 
 
 if __name__ == '__main__':
-    run_api_explain_example()
+    run_api_explain_example(visualization=True, timeout=5)
