@@ -1,3 +1,4 @@
+import logging
 import pathlib
 
 from examples.simple.classification.classification_pipelines import classification_complex_pipeline
@@ -9,7 +10,7 @@ def run_log_example(log_file):
     train_data, _ = get_case_train_test_data()
 
     # Use default_log if you do not have json config file for log
-    log = Log(log_file=log_file).get_adapter(prefix=pathlib.Path(__file__).stem)
+    log = Log(log_file=log_file, output_logging_level=logging.DEBUG).get_adapter(prefix=pathlib.Path(__file__).stem)
 
     log.info('start creating pipeline')
     pipeline = classification_complex_pipeline()
