@@ -8,6 +8,7 @@ import pandas as pd
 from fedot.api.api_utils.api_composer import ApiComposer
 from fedot.api.api_utils.api_data import ApiDataProcessor
 from fedot.api.api_utils.api_data_analyser import DataAnalyser
+from fedot.api.api_utils.data_definition import FeaturesType, TargetType
 from fedot.api.api_utils.metrics import ApiMetrics
 from fedot.api.api_utils.params import ApiParams
 from fedot.api.api_utils.predefined_model import PredefinedModel
@@ -30,9 +31,6 @@ from fedot.utilities.project_import_export import export_project_to_zip, import_
 
 NOT_FITTED_ERR_MSG = 'Model not fitted yet'
 
-FeaturesType = Union[str, np.ndarray, pd.DataFrame, InputData, dict]
-TargetType = Union[str, np.ndarray, pd.Series, dict]
-
 
 class Fedot:
     """Main class for FEDOT API.
@@ -71,7 +69,8 @@ class Fedot:
         num_of_generations: number of generations for composer
         keep_n_best: Number of the best individuals of previous generation to keep in next generation.
         available_operations: list of model names to use
-        early_stopping_generations: composer will stop after ``n`` generation without improving
+        early_stopping_iterations: composer will stop after ``n`` generation without improving
+        early_stopping_timeout: stagnation timeout in minutes: composer will stop after ``n`` minutes without improving
         with_tuning: allow hyperparameters tuning for the model
         cv_folds: number of folds for cross-validation
         validation_blocks: number of validation blocks for time series forecasting
@@ -79,7 +78,7 @@ class Fedot:
         initial_assumption: initial assumption for composer
         genetic_scheme: name of the genetic scheme
         history_folder: name of the folder for composing history
-        metric:  metric for quality calculation during composing, also is used for tuning if with_tuning=True
+        metric:  metric for quality calculation during composing, also is used for tuning if ``with_tuning=True``
         collect_intermediate_metric: save metrics for intermediate (non-root) nodes in pipeline
         preset: name of preset for model building (e.g. 'best_quality', 'fast_train', 'gpu'):
 
@@ -133,6 +132,7 @@ class Fedot:
 
         self.target: Optional[TargetType] = None
         self.prediction: Optional[OutputData] = None
+        self._is_in_sample_prediction = True
         self.train_data: Optional[InputData] = None
         self.test_data: Optional[InputData] = None
 
@@ -142,7 +142,7 @@ class Fedot:
         self.history: Optional[OptHistory] = None
 
     def fit(self,
-            features: Union[str, np.ndarray, pd.DataFrame, InputData, dict],
+            features: FeaturesType,
             target: TargetType = 'target',
             predefined_model: Union[str, Pipeline] = None) -> Pipeline:
         """Fits the graph with a predefined structure or compose and fit the new graph
@@ -167,6 +167,7 @@ class Fedot:
         self.data_processor.accept_and_apply_recommendations(self.train_data, recommendations)
         self.params.accept_and_apply_recommendations(self.train_data, recommendations)
         self._init_remote_if_necessary()
+        self.params.update_available_operations_by_preset(self.train_data)
         self.params.api_params['train_data'] = self.train_data
 
         if predefined_model is not None:
@@ -189,18 +190,29 @@ class Fedot:
         self.current_pipeline.preprocessor = merge_preprocessors(self.data_processor.preprocessor,
                                                                  self.current_pipeline.preprocessor)
 
-        self.params.api_params['logger'].message(f'Final pipeline: {str(self.current_pipeline)}')
+        self.params.api_params['logger'].message(f'Final pipeline: {self.current_pipeline.structure}')
 
         return self.current_pipeline
 
     def predict(self,
                 features: FeaturesType,
-                save_predictions: bool = False) -> np.ndarray:
-        """Predicts new target using already fitted model
+                save_predictions: bool = False,
+                in_sample: bool = True,
+                validation_blocks: Optional[int] = None) -> np.ndarray:
+        """Predicts new target using already fitted model.
+
+        For time-series performs forecast with depth ``forecast_length`` if ``in_sample=False``.
+        If ``in_sample=True`` performs in-sample forecast using features as sample.
 
         Args:
             features: the array with features of test data
             save_predictions: if ``True`` - save predictions as csv-file in working directory
+            in_sample: used while time-series prediction. If ``in_sample=True`` performs in-sample forecast using
+                features with number if iterations specified in ``validation_blocks``.
+            validation_blocks: number of validation blocks for in-sample forecast.
+                If ``validation_blocks = None`` uses number of validation blocks set during model initialization
+                (default is 2).
+
 
         Returns:
             the array with prediction values
@@ -209,9 +221,13 @@ class Fedot:
             raise ValueError(NOT_FITTED_ERR_MSG)
 
         self.test_data = self.data_processor.define_data(target=self.target, features=features, is_predict=True)
+        self._is_in_sample_prediction = in_sample
+        validation_blocks = validation_blocks or self.params.api_params.get('validation_blocks')
 
         self.prediction = self.data_processor.define_predictions(current_pipeline=self.current_pipeline,
-                                                                 test_data=self.test_data)
+                                                                 test_data=self.test_data,
+                                                                 in_sample=self._is_in_sample_prediction,
+                                                                 validation_blocks=validation_blocks)
 
         if save_predictions:
             self.save_predict(self.prediction)
@@ -270,12 +286,15 @@ class Fedot:
 
         forecast_length = self.train_data.task.task_params.forecast_length
         horizon = horizon if horizon is not None else forecast_length
-        pre_history = pre_history if pre_history is not None else self.train_data
+        if pre_history is None:
+            pre_history = self.train_data
+            pre_history.target = None
         self.test_data = self.data_processor.define_data(target=self.target,
                                                          features=pre_history,
                                                          is_predict=True)
         predict = out_of_sample_ts_forecast(self.current_pipeline, self.test_data, horizon)
         self.prediction = convert_forecast_to_output(self.test_data, predict)
+        self._is_in_sample_prediction = False
         if save_predictions:
             self.save_predict(self.prediction)
         return self.prediction.predict
@@ -307,15 +326,19 @@ class Fedot:
                          objectives_names=metric_names,
                          show=True)
 
-    def plot_prediction(self, target: Optional[Any] = None):
+    def plot_prediction(self, in_sample: Optional[bool] = None, target: Optional[Any] = None):
         """Plots the prediction obtained from graph
 
         Args:
+            in_sample: if current prediction is in_sample (for time-series forecasting).
+            Plots predictions as future values
             target: user-specified name of target variable for :obj:`MultiModalData`
+
         """
         if self.prediction is not None:
             if self.params.api_params['task'].task_type == TaskTypesEnum.ts_forecasting:
-                plot_forecast(self.test_data, self.prediction, target)
+                in_sample = in_sample or self._is_in_sample_prediction
+                plot_forecast(self.test_data, self.prediction, in_sample, target)
             elif self.params.api_params['task'].task_type == TaskTypesEnum.regression:
                 plot_biplot(self.prediction)
             elif self.params.api_params['task'].task_type == TaskTypesEnum.classification:
@@ -330,13 +353,19 @@ class Fedot:
 
     def get_metrics(self,
                     target: Union[np.ndarray, pd.Series] = None,
-                    metric_names: Union[str, List[str]] = None) -> dict:
+                    metric_names: Union[str, List[str]] = None,
+                    in_sample: Optional[bool] = None,
+                    validation_blocks: Optional[int] = None) -> dict:
         """Gets quality metrics for the fitted graph
 
         Args:
-
             target: the array with target values of test data
             metric_names: the names of required metrics
+            in_sample: used for time-series forecasting.
+                If True prediction will be obtained as ``.predict(..., in_sample=True)``.
+            validation_blocks: number of validation blocks for in-sample forecast.
+                If ``validation_blocks = None`` uses number of validation blocks set during model initialization
+                (default is 2).
 
         Returns:
             the values of quality metrics
@@ -368,7 +397,10 @@ class Fedot:
                 if metric_name == "roc_auc":  # for roc-auc we need probabilities
                     prediction.predict = self.predict_proba(self.test_data)
                 else:
-                    prediction.predict = self.predict(self.test_data)
+                    if in_sample is not None:
+                        self._is_in_sample_prediction = in_sample
+                    prediction.predict = self.predict(self.test_data, in_sample=self._is_in_sample_prediction,
+                                                      validation_blocks=validation_blocks)
                 real = deepcopy(self.test_data)
 
                 # Work inplace - correct predictions
@@ -379,7 +411,7 @@ class Fedot:
 
                 metric_value = abs(metric_cls.metric(reference=real,
                                                      predicted=prediction))
-                calculated_metrics[metric_name] = metric_value
+                calculated_metrics[metric_name] = round(metric_value, 3)
 
         return calculated_metrics
 
@@ -408,14 +440,14 @@ class Fedot:
         self.predict(self.test_data)
 
     def explain(self, features: FeaturesType = None,
-                method: str = 'surrogate_dt', visualize: bool = True, **kwargs) -> 'Explainer':
+                method: str = 'surrogate_dt', visualization: bool = True, **kwargs) -> 'Explainer':
         """Creates explanation for *current_pipeline* according to the selected 'method'.
             An :obj:`Explainer` instance will return.
 
         Args:
             features: samples to be explained. If ``None``, ``train_data`` from last fit will be used.
             method: explanation method, defaults to ``surrogate_dt``
-            visualize: print and plot the explanation simultaneously, defaults to ``True``.
+            visualization: print and plot the explanation simultaneously, defaults to ``True``.
         Notes:
             The explanation can be retrieved later by executing :obj:`explainer.visualize()`
         """
@@ -426,13 +458,13 @@ class Fedot:
             data = self.data_processor.define_data(features=features,
                                                    is_predict=False)
         explainer = explain_pipeline(pipeline=pipeline, data=data, method=method,
-                                     visualize=visualize, **kwargs)
+                                     visualization=visualization, **kwargs)
 
         return explainer
 
     def _init_remote_if_necessary(self):
         remote = RemoteEvaluator()
-        if remote.use_remote and remote.remote_task_params is not None:
+        if remote.is_enabled and remote.remote_task_params is not None:
             task = self.params.api_params['task']
             if task.task_type is TaskTypesEnum.ts_forecasting:
                 task_str = \
@@ -443,7 +475,7 @@ class Fedot:
             remote.remote_task_params.task_type = task_str
             remote.remote_task_params.is_multi_modal = isinstance(self.train_data, MultiModalData)
 
-            if isinstance(self.target, str):
+            if isinstance(self.target, str) and remote.remote_task_params.target is None:
                 remote.remote_task_params.target = self.target
 
     def _train_pipeline_on_full_dataset(self, recommendations: dict, full_train_not_preprocessed):
