@@ -5,10 +5,12 @@ import numpy as np
 from sklearn.metrics import (accuracy_score, f1_score, log_loss, mean_absolute_error, mean_absolute_percentage_error,
                              mean_squared_error, mean_squared_log_error, precision_score, r2_score, roc_auc_score,
                              silhouette_score, roc_curve, auc)
+
 from fedot.core.data.data import InputData, OutputData
 from fedot.core.repository.dataset_types import DataTypesEnum
 from fedot.core.repository.tasks import TaskTypesEnum
 from fedot.core.pipelines.ts_wrappers import in_sample_ts_forecast
+from fedot.core.pipelines.pipeline import Pipeline
 
 
 def from_maximised_metric(metric_func):
@@ -50,6 +52,11 @@ class QualityMetric:
     output_mode = 'default'
     default_value = 0
 
+    @staticmethod
+    @abstractmethod
+    def metric(reference: InputData, predicted: OutputData) -> float:
+        raise NotImplementedError()
+
     @classmethod
     def get_value(cls, pipeline: 'Pipeline', reference_data: InputData,
                   validation_blocks: int = None) -> float:
@@ -63,7 +70,9 @@ class QualityMetric:
                 reference_data, results = cls._in_sample_prediction(pipeline, reference_data, validation_blocks)
             metric = cls.metric(reference_data, results)
         except Exception as ex:
+            # TODO: use log instead of stdout
             print(f'Metric evaluation error: {ex}')
+
         return metric
 
     @classmethod
@@ -115,16 +124,14 @@ class QualityMetric:
     def _in_sample_prediction(pipeline, data, validation_blocks):
         """ Performs in-sample pipeline validation for time series prediction """
 
-        # Get number of validation blocks per each fold
-        horizon = data.task.task_params.forecast_length * validation_blocks
+        horizon = int(validation_blocks * data.task.task_params.forecast_length)
+
+        actual_values = data.target[-horizon:]
 
         predicted_values = in_sample_ts_forecast(pipeline=pipeline,
                                                  input_data=data,
                                                  horizon=horizon)
 
-        # Clip actual data by the forecast horizon length
-        actual_values = data.target[-horizon:]
-
         # Wrap target and prediction arrays into OutputData and InputData
         results = OutputData(idx=np.arange(0, len(predicted_values)), features=predicted_values,
                              predict=predicted_values, task=data.task, target=predicted_values,
@@ -134,11 +141,6 @@ class QualityMetric:
 
         return reference_data, results
 
-    @staticmethod
-    @abstractmethod
-    def metric(reference: InputData, predicted: OutputData) -> float:
-        raise NotImplementedError()
-
 
 class RMSE(QualityMetric):
     default_value = sys.maxsize
