@@ -1,9 +1,9 @@
 from abc import ABC, abstractmethod
 from os import PathLike
-from typing import Tuple, Dict, List, Sequence, Union, TypeVar, Optional
+from typing import Dict, List, Optional, Sequence, Union, Tuple, TypeVar
 
 from fedot.core.dag.graph_node import GraphNode
-from fedot.core.visualisation.graph_viz import GraphVisualiser, NodeColorType
+from fedot.core.visualisation.graph_viz import GraphVisualizer, NodeColorType
 
 NodeType = TypeVar('NodeType', bound=GraphNode, covariant=False, contravariant=False)
 
@@ -51,7 +51,7 @@ class Graph(ABC):
         raise NotImplementedError()
 
     @abstractmethod
-    def delete_subtree(self, subroot: GraphNode):
+    def delete_subtree(self, subtree: GraphNode):
         """Deletes given node with all its parents.
         Deletes all edges from removed nodes to remaining graph nodes
 
@@ -61,27 +61,6 @@ class Graph(ABC):
         """
         raise NotImplementedError()
 
-    @abstractmethod
-    def distance_to_root_level(self, node: GraphNode) -> int:
-        """Gets distance to the final output node
-
-        Args:
-            node: search starting point
-        """
-        raise NotImplementedError()
-
-    @abstractmethod
-    def nodes_from_layer(self, layer_number: int) -> Sequence[GraphNode]:
-        """Gets all the nodes from the chosen layer up to the surface
-
-        Args:
-            layer_number: max height of diving
-
-        Returns:
-            all nodes from the surface to the ``layer_number`` layer
-        """
-        raise NotImplementedError()
-
     @abstractmethod
     def node_children(self, node: GraphNode) -> Sequence[Optional[GraphNode]]:
         """Returns all children of the ``node``
@@ -115,16 +94,6 @@ class Graph(ABC):
         """
         raise NotImplementedError()
 
-    @abstractmethod
-    def get_nodes_degrees(self) -> Sequence[int]:
-        """Nodes degree as the number of edges the node has:
-            ``degree = #input_edges + #out_edges``
-
-        Returns:
-            nodes degrees ordered according to the nx_graph representation of this graph
-        """
-        raise NotImplementedError()
-
     @abstractmethod
     def get_edges(self) -> Sequence[Tuple[GraphNode, GraphNode]]:
         """Gets all available edges in this graph
@@ -134,6 +103,34 @@ class Graph(ABC):
         """
         raise NotImplementedError()
 
+    def get_nodes_by_name(self, name: str) -> List[GraphNode]:
+        """Returns list of nodes with the required ``name``
+
+        Args:
+            name: name to filter by
+
+        Returns:
+            list: relevant nodes (empty if there are no such nodes)
+        """
+
+        appropriate_nodes = filter(lambda x: x.name == name, self.nodes)
+
+        return list(appropriate_nodes)
+
+    def get_node_by_uid(self, uid: str) -> Optional[GraphNode]:
+        """Returns node with the required ``uid``
+
+        Args:
+            uid: uid of node to filter by
+
+        Returns:
+            Optional[Node]: relevant node (None if there is no such node)
+        """
+
+        appropriate_nodes = list(filter(lambda x: x.uid == uid, self.nodes))
+
+        return appropriate_nodes[0] if appropriate_nodes else None
+
     @abstractmethod
     def __eq__(self, other_graph: 'Graph') -> bool:
         """Compares this graph with the ``other_graph``
@@ -196,9 +193,10 @@ class Graph(ABC):
 
         return len(self.nodes)
 
-    def show(self, save_path: Optional[Union[PathLike, str]] = None, engine: str = 'matplotlib',
-             node_color: Optional[NodeColorType] = None, dpi: int = 300,
-             node_size_scale: float = 1.0, font_size_scale: float = 1.0, edge_curvature_scale: float = 1.0):
+    def show(self, save_path: Optional[Union[PathLike, str]] = None, engine: Optional[str] = None,
+             node_color: Optional[NodeColorType] = None, dpi: Optional[int] = None,
+             node_size_scale: Optional[float] = None, font_size_scale: Optional[float] = None,
+             edge_curvature_scale: Optional[float] = None):
         """Visualizes graph or saves its picture to the specified ``path``
 
         Args:
@@ -210,8 +208,8 @@ class Graph(ABC):
             edge_curvature_scale: use to make edges more or less curved. Supported only for the engine 'matplotlib'.
             dpi: DPI of the output image. Not supported for the engine 'pyvis'.
         """
-        GraphVisualiser().visualise(self, save_path, engine, node_color, dpi, node_size_scale, font_size_scale,
-                                    edge_curvature_scale)
+        GraphVisualizer(self).visualise(save_path, engine, node_color, dpi, node_size_scale, font_size_scale,
+                                        edge_curvature_scale)
 
     @property
     def graph_description(self) -> Dict:
