@@ -1,6 +1,7 @@
 from typing import Sequence, Optional, Callable
 
-from fedot.core.adapter import BaseOptimizationAdapter, DirectAdapter
+from fedot.core.adapter import BaseOptimizationAdapter
+from fedot.core.adapter.adapter import IdentityAdapter
 from fedot.core.dag.graph import Graph
 from fedot.core.log import default_log
 
@@ -8,12 +9,18 @@ from fedot.core.log import default_log
 VerifierRuleType = Callable[..., bool]
 
 
+class VerificationError(ValueError):
+    pass
+
+
 class GraphVerifier:
     def __init__(self, rules: Sequence[VerifierRuleType] = (),
-                 adapter: Optional[BaseOptimizationAdapter] = None):
-        self._adapter = adapter or DirectAdapter()
+                 adapter: Optional[BaseOptimizationAdapter] = None,
+                 raise_on_failure: bool = False):
+        self._adapter = adapter or IdentityAdapter()
         self._rules = rules
         self._log = default_log(self)
+        self._raise = raise_on_failure
 
     def __call__(self, graph: Graph) -> bool:
         return self.verify(graph)
@@ -26,7 +33,11 @@ class GraphVerifier:
                 if adapt(rule)(graph) is False:
                     return False
             except ValueError as err:
-                self._log.debug(f'Graph verification failed with error <{err}> '
-                                f'for rule={rule} on graph={graph.descriptive_id}.')
-                return False
+                msg = f'Graph verification failed with error <{err}> '\
+                      f'for rule={rule} on graph={graph.descriptive_id}.'
+                if self._raise:
+                    raise VerificationError(msg)
+                else:
+                    self._log.debug(msg)
+                    return False
         return True
