@@ -63,7 +63,7 @@ class AtomizedModelTemplate(OperationTemplateAbstract):
     def export_operation(self, path: str):
         absolute_path = os.path.join(path, self.atomized_model_json_path)
         check_existing_path(absolute_path)
-        self.pipeline_template.export_pipeline(absolute_path)
+        self.pipeline_template.export_pipeline(absolute_path, create_subdir=False)
 
     def import_json(self, operation_object: dict):
         required_fields = ['operation_id', 'operation_type', 'nodes_from', 'atomized_model_json_path']
