@@ -1,19 +1,18 @@
+from typing import Optional
+
 from fedot.core.data.data import OutputData
-from fedot.core.log import Log
 from fedot.core.operations.operation import Operation
 from fedot.core.repository.operation_types_repository import OperationMetaInfo, OperationTypesRepository
 
 
 class DataOperation(Operation):
-    """
-    Class with fit/predict methods defining the evaluation strategy for the task
+    """Class with ``fit``/``predict`` methods defining the evaluation strategy for the task
 
-    :param operation_type: name of the data operation
-    :param log: Log object to record messages
+    Args:
+        operation_type: name of the data operation
     """
-
-    def __init__(self, operation_type: str, log: Log = None):
-        super().__init__(operation_type, log)
+    def __init__(self, operation_type: str):
+        super().__init__(operation_type)
         self.operations_repo = OperationTypesRepository('data_operation')
 
     @property
@@ -25,10 +24,8 @@ class DataOperation(Operation):
 
     @staticmethod
     def assign_tabular_column_types(output_data: OutputData, output_mode: str) -> OutputData:
-        """
-        Assign new column types if it necessary. By default, all data operations
-        must define column types at lower levels (EvalStrategies and Implementations).
+        """Assign new column types if it necessary.
+        By default, all data operations must define column types at lower levels (:obj:`EvalStrategies` and :obj:`Implementations`).
         In some cases the previously defined data types are passed.
         """
-        # There are already assigned types for columns
         return output_data
