@@ -4,7 +4,9 @@ from typing import Optional
 from sklearn.cluster import KMeans as SklearnKmeans
 
 from fedot.core.data.data import InputData, OutputData
+from fedot.core.operations.operation_parameters import OperationParameters
 from fedot.core.operations.evaluation.evaluation_interfaces import SkLearnEvaluationStrategy
+from fedot.core.utilities.random import RandomStateHandler
 
 warnings.filterwarnings("ignore", category=UserWarning)
 
@@ -14,40 +16,32 @@ class SkLearnClusteringStrategy(SkLearnEvaluationStrategy):
         'kmeans': SklearnKmeans
     }
 
-    def __init__(self, operation_type: str, params: Optional[dict] = None):
+    def __init__(self, operation_type: str, params: Optional[OperationParameters] = None):
         super().__init__(operation_type, params)
+        if not params:
+            self.params_for_fit.update(n_clusters=2)
         self.operation_impl = self._convert_to_operation(operation_type)
-        self.params_for_fit = params
 
     def fit(self, train_data: InputData):
         """
         Fit method for clustering task
 
         :param train_data: data used for model training
-        :return:
         """
 
         warnings.filterwarnings("ignore", category=RuntimeWarning)
-        if self.params_for_fit:
-            operation_implementation = self.operation_impl(**self.params_for_fit)
-        else:
-            operation_implementation = self.operation_impl(n_clusters=2)
-
-        operation_implementation.fit(train_data.features)
+        operation_implementation = self.operation_impl(**self.params_for_fit.to_dict())
+        with RandomStateHandler():
+            operation_implementation.fit(train_data.features)
         return operation_implementation
 
-    def predict(self, trained_operation, predict_data: InputData,
-                is_fit_pipeline_stage: bool) -> OutputData:
+    def predict(self, trained_operation, predict_data: InputData) -> OutputData:
         """
         Predict method for clustering task
         :param trained_operation: operation object
         :param predict_data: data used for prediction
-        :param is_fit_pipeline_stage: is this fit or predict stage for pipeline
-        :return :
         """
         prediction = trained_operation.predict(predict_data.features)
-
-        # Convert prediction to output (if it is required)
         converted = self._convert_to_output(prediction, predict_data)
         return converted
 
