@@ -1,8 +1,14 @@
 import warnings
 
-import cudf
+from fedot.utilities.requirements_notificator import warn_requirement
 
-from fedot.core.data.data import InputData
+try:
+    import cudf
+except ModuleNotFoundError:
+    warn_requirement('cudf')
+    cudf = None
+
+from fedot.core.data.data import InputData, OutputData
 from fedot.core.operations.evaluation.gpu.common import CuMLEvaluationStrategy
 
 warnings.filterwarnings("ignore", category=UserWarning)
@@ -11,21 +17,18 @@ warnings.filterwarnings("ignore", category=UserWarning)
 class CuMLClassificationStrategy(CuMLEvaluationStrategy):
     """ Strategy for applying classification algorithms from Sklearn library """
 
-    def predict(self, trained_operation, predict_data: InputData,
-                is_fit_pipeline_stage: bool):
+    def predict(self, trained_operation, predict_data: InputData) -> OutputData:
         """
-        Predict method for classification task
-
+        Predict method for regression task for predict stage
         :param trained_operation: model object
         :param predict_data: data used for prediction
-        :param is_fit_pipeline_stage: is this fit or predict stage for pipeline
-        :return: prediction target
+        :return:
         """
+
         features = cudf.DataFrame(predict_data.features.astype('float32'))
 
         prediction = self._sklearn_compatible_prediction(trained_operation,
                                                          features)
-
-        # Convert prediction to output (if it is required)
         converted = self._convert_to_output(prediction, predict_data)
+
         return converted
