@@ -1,9 +1,12 @@
 from abc import ABC, abstractmethod
+from copy import deepcopy
 from typing import Optional
 
 import numpy as np
-from fedot.core.data.data import OutputData
-from fedot.core.log import Log, default_log
+
+from fedot.core.data.data import OutputData, InputData
+from fedot.core.log import default_log
+from fedot.core.operations.operation_parameters import OperationParameters
 from fedot.core.repository.dataset_types import DataTypesEnum
 
 
@@ -13,11 +16,11 @@ class DataOperationImplementation(ABC):
     optimizer on it
     """
 
-    def __init__(self):
-        pass
+    def __init__(self, params: Optional[OperationParameters] = None):
+        self.params = params or OperationParameters()
 
     @abstractmethod
-    def fit(self, input_data):
+    def fit(self, input_data: InputData):
         """ Method fit operation on a dataset
 
         :param input_data: data with features, target and ids to process
@@ -25,24 +28,31 @@ class DataOperationImplementation(ABC):
         raise NotImplementedError()
 
     @abstractmethod
-    def transform(self, input_data, is_fit_pipeline_stage: Optional[bool]):
-        """ Method apply transform operation on a dataset
+    def transform(self, input_data: InputData) -> OutputData:
+        """ Method apply transform operation on a dataset for predict stage
 
         :param input_data: data with features, target and ids to process
-        :param is_fit_pipeline_stage: is this fit or predict stage for pipeline
         """
         raise NotImplementedError()
 
-    @abstractmethod
-    def get_params(self):
+    def transform_for_fit(self, input_data: InputData) -> OutputData:
+        """ Method apply transform operation on a dataset for fit stage.
+        Allows to implement transform method different from main transform method
+        if another behaviour for fit graph stage is needed.
+
+        :param input_data: data with features, target and ids to process
+        """
+        return self.transform(input_data)
+
+    def get_params(self) -> OperationParameters:
         """ Method return parameters, which can be optimized for particular
         operation
         """
-        raise NotImplementedError()
+        return deepcopy(self.params)
 
     @staticmethod
-    def _convert_to_output(input_data, predict,
-                           data_type=DataTypesEnum.table):
+    def _convert_to_output(input_data: InputData, predict: np.ndarray,
+                           data_type: DataTypesEnum = DataTypesEnum.table) -> OutputData:
         """ Method prepare prediction of operation as OutputData object """
 
         converted = _convert_to_output_function(input_data, predict, data_type)
@@ -56,14 +66,13 @@ class EncodedInvariantImplementation(DataOperationImplementation):
     vectors
     """
 
-    def __init__(self, **params: Optional[dict]):
-        super().__init__()
+    def __init__(self, params: Optional[OperationParameters]):
+        super().__init__(params)
         self.operation = None
         self.ids_to_process = None
         self.bool_ids = None
-        self.params = params
 
-    def fit(self, input_data):
+    def fit(self, input_data: InputData):
         """ Method for fit transformer with automatic determination
         of boolean features, with which there is no need to make transformation
 
@@ -86,12 +95,11 @@ class EncodedInvariantImplementation(DataOperationImplementation):
 
         return self.operation
 
-    def transform(self, input_data, is_fit_pipeline_stage: Optional[bool]):
+    def transform(self, input_data: InputData) -> OutputData:
         """
-        The method that transforms the source features using "operation"
+        The method that transforms the source features using "operation" for predict stage
 
         :param input_data: tabular data with features, target and ids to process
-        :param is_fit_pipeline_stage: is this fit or predict stage for pipeline
         :return output_data: output data with transformed features table
         """
         source_features_shape = input_data.features.shape
@@ -129,10 +137,7 @@ class EncodedInvariantImplementation(DataOperationImplementation):
 
         return transformed_features
 
-    def get_params(self):
-        return self.operation.get_params()
-
-    def _update_column_types(self, source_features_shape, output_data: OutputData):
+    def _update_column_types(self, source_features_shape, output_data: OutputData) -> OutputData:
         """
         Update column types after applying operations.
         If new columns added, new type for them are defined
@@ -159,7 +164,7 @@ class EncodedInvariantImplementation(DataOperationImplementation):
 
         # For every column in table make check
         for column_id in range(0, columns_amount):
-            column = features[:, column_id] if columns_amount >= 1 else features
+            column = features[:, column_id] if columns_amount > 1 else features
             if len(np.unique(column)) > 2:
                 non_bool_ids.append(column_id)
             else:
@@ -174,14 +179,12 @@ class ModelImplementation(ABC):
     optimizer on it
     """
 
-    def __init__(self, log: Log):
-        if not log:
-            self.log = default_log(__name__)
-        else:
-            self.log = log
+    def __init__(self, params: OperationParameters = None):
+        self.log = default_log(self)
+        self.params = params or OperationParameters()
 
     @abstractmethod
-    def fit(self, input_data):
+    def fit(self, input_data: InputData):
         """ Method fit model on a dataset
 
         :param input_data: data with features, target and ids to process
@@ -189,32 +192,39 @@ class ModelImplementation(ABC):
         raise NotImplementedError()
 
     @abstractmethod
-    def predict(self, input_data, is_fit_pipeline_stage: Optional[bool]):
+    def predict(self, input_data: InputData) -> OutputData:
         """ Method make prediction
 
         :param input_data: data with features, target and ids to process
-        :param is_fit_pipeline_stage: is this fit or predict stage for pipeline
         """
         raise NotImplementedError()
 
-    @abstractmethod
-    def get_params(self):
+    def predict_for_fit(self, input_data: InputData) -> OutputData:
+        """ Method make prediction while graph fitting.
+        Allows to implement predict method different from main predict method
+        if another behaviour for fit graph stage is needed.
+
+        :param input_data: data with features, target and ids to process
+        """
+        return self.predict(input_data)
+
+    def get_params(self) -> OperationParameters:
         """ Method return parameters, which can be optimized for particular
         operation
         """
-        raise NotImplementedError()
+        return deepcopy(self.params)
 
     @staticmethod
-    def _convert_to_output(input_data, predict,
-                           data_type=DataTypesEnum.table):
+    def _convert_to_output(input_data: InputData, predict: np.array,
+                           data_type: DataTypesEnum = DataTypesEnum.table):
         """ Method prepare prediction of operation as OutputData object """
 
         converted = _convert_to_output_function(input_data, predict, data_type)
         return converted
 
 
-def _convert_to_output_function(input_data, transformed_features,
-                                data_type=DataTypesEnum.table):
+def _convert_to_output_function(input_data: InputData, transformed_features: np.array,
+                                data_type: DataTypesEnum = DataTypesEnum.table):
     """ Function prepare prediction of operation as OutputData object
 
     :param input_data: data with features, target and ids to process
