@@ -3,6 +3,7 @@ from random import choice, random
 from typing import Callable, Union, Iterable, Tuple, TYPE_CHECKING
 
 from fedot.core.adapter import register_native
+from fedot.core.dag.graph_utils import nodes_from_layer, node_depth
 from fedot.core.optimisers.gp_comp.gp_operators import equivalent_subtree, replace_subtrees
 from fedot.core.optimisers.gp_comp.operators.operator import PopulationT, Operator
 from fedot.core.optimisers.gp_comp.pipeline_composer_requirements import PipelineComposerRequirements
@@ -104,11 +105,12 @@ def subtree_crossover(graph_first: OptGraph, graph_second: OptGraph, max_depth:
     min_second_layer = 1 if random_layer_in_graph_first == 0 and graph_second.depth > 1 else 0
     random_layer_in_graph_second = choice(range(min_second_layer, graph_second.depth))
 
-    node_from_graph_first = choice(graph_first.nodes_from_layer(random_layer_in_graph_first))
-    node_from_graph_second = choice(graph_second.nodes_from_layer(random_layer_in_graph_second))
+    node_from_graph_first = choice(nodes_from_layer(graph_first, random_layer_in_graph_first))
+    node_from_graph_second = choice(nodes_from_layer(graph_second, random_layer_in_graph_second))
 
-    replace_subtrees(graph_first, graph_second, node_from_graph_first, node_from_graph_second,
-                     random_layer_in_graph_first, random_layer_in_graph_second, max_depth)
+    if is_crossover_correct(graph_first, graph_second):
+        replace_subtrees(graph_first, graph_second, node_from_graph_first, node_from_graph_second,
+                         random_layer_in_graph_first, random_layer_in_graph_second, max_depth)
 
     return graph_first, graph_second
 
@@ -117,15 +119,28 @@ def subtree_crossover(graph_first: OptGraph, graph_second: OptGraph, max_depth:
 def one_point_crossover(graph_first: OptGraph, graph_second: OptGraph, max_depth: int) -> Tuple[OptGraph, OptGraph]:
     """Finds common structural parts between two trees, and after that randomly
     chooses the location of nodes, subtrees of which will be swapped"""
-    pairs_of_nodes = equivalent_subtree(graph_first, graph_second)
-    if pairs_of_nodes:
-        node_from_graph_first, node_from_graph_second = choice(pairs_of_nodes)
+    if is_crossover_correct(graph_first, graph_second):
+        pairs_of_nodes = equivalent_subtree(graph_first, graph_second)
+        if pairs_of_nodes:
+            node_from_graph_first, node_from_graph_second = choice(pairs_of_nodes)
 
-        layer_in_graph_first = \
-            graph_first.root_node.distance_to_primary_level - node_from_graph_first.distance_to_primary_level
-        layer_in_graph_second = \
-            graph_second.root_node.distance_to_primary_level - node_from_graph_second.distance_to_primary_level
+            layer_in_graph_first = graph_first.depth - node_depth(node_from_graph_first)
+            layer_in_graph_second = graph_second.depth - node_depth(node_from_graph_second)
 
-        replace_subtrees(graph_first, graph_second, node_from_graph_first, node_from_graph_second,
-                         layer_in_graph_first, layer_in_graph_second, max_depth)
+            replace_subtrees(graph_first, graph_second, node_from_graph_first, node_from_graph_second,
+                             layer_in_graph_first, layer_in_graph_second, max_depth)
     return graph_first, graph_second
+
+
+def is_crossover_correct(graph_first: OptGraph, graph_second: OptGraph):
+    # crossover with custom models and exog_ts is unsafe
+    for node in graph_first.nodes:
+        operation_id = node.content['name']
+        if 'exog_ts' in operation_id or 'custom' in operation_id:
+            return False
+
+    for node in graph_second.nodes:
+        operation_id = node.content['name']
+        if 'exog_ts' in operation_id or 'custom' in operation_id:
+            return False
+    return True
