@@ -1,16 +1,13 @@
 import datetime
 from abc import ABC
 
-from fedot.core.log import Log, default_log
+from fedot.core.log import default_log
 
 
 class Timer(ABC):
-    def __init__(self, timeout: datetime.timedelta = None, log: Log = None):
+    def __init__(self, timeout: datetime.timedelta = None):
         self.process_terminated = False
-        if not log:
-            self.log = default_log(__name__)
-        else:
-            self.log = log
+        self.log = default_log(self)
         self.timeout = timeout
 
     def __enter__(self):
@@ -23,7 +20,7 @@ class Timer(ABC):
 
     @property
     def spent_time(self) -> datetime.timedelta:
-        return datetime.datetime.now() - self.start
+        return datetime.datetime.now() - self.start_time
 
     @property
     def minutes_from_start(self) -> float:
@@ -45,8 +42,8 @@ class Timer(ABC):
 
 
 class OptimisationTimer(Timer):
-    def __init__(self, timeout: datetime.timedelta = None, log: Log = None):
-        super().__init__(timeout=timeout, log=log)
+    def __init__(self, timeout: datetime.timedelta = None):
+        super().__init__(timeout=timeout)
         self.init_time = 0
 
     def _is_next_iteration_possible(self, time_constraint: float, iteration_num: int = None) -> bool:
@@ -80,3 +77,7 @@ class OptimisationTimer(Timer):
         self.log.info(f'Composition time: {round(self.minutes_from_start, 3)} min')
         if self.process_terminated:
             self.log.info('Algorithm was terminated due to processing time limit')
+
+
+def get_forever_timer() -> Timer:
+    return Timer(timeout=None)
