@@ -1,8 +1,7 @@
 from copy import deepcopy
 from typing import List, Union, Optional, Tuple, Dict
 
-from fedot.core.dag.graph import Graph
-from fedot.core.dag.graph_operator import GraphOperator
+from fedot.core.dag.linked_graph import LinkedGraph
 from fedot.core.pipelines.node import Node, PrimaryNode, SecondaryNode
 from fedot.core.pipelines.pipeline import Pipeline
 
@@ -54,6 +53,7 @@ class PipelineBuilder:
 
         :param operation_type: operations for new nodes, either as an operation name
             or as a tuple of operation name and operation parameters.
+        :param branch_idx: index of the branch for branching its tip
         """
         for operation in operation_type:
             operation, params = self._unpack_operation(operation)
@@ -179,7 +179,7 @@ def merge_pipeline_builders(previous: PipelineBuilder, following: PipelineBuilde
         return following
 
     lhs_nodes_final = previous.to_nodes()
-    rhs_tmp_graph = GraphOperator(following.to_nodes())
+    rhs_tmp_graph = LinkedGraph(following.to_nodes())
     rhs_nodes_initial = list(filter(lambda node: not node.nodes_from, rhs_tmp_graph.nodes))
 
     # If merging one-to-one or one-to-many
