@@ -7,6 +7,7 @@ from sklearn.model_selection._split import _BaseKFold
 from fedot.core.data.data import InputData
 from fedot.core.data.data_split import train_test_data_setup
 from fedot.core.log import LoggerAdapter, default_log
+from fedot.core.repository.dataset_types import DataTypesEnum
 
 
 class OneFoldInputDataSplit:
@@ -54,6 +55,8 @@ class TsInputDataSplit(TimeSeriesSplit):
         data_for_split = np.array(input_data.target)
 
         for train_ids, test_ids in super().split(data_for_split):
+            if len(train_ids) <= len(test_ids):
+                raise ValueError("Train size will be too small with selected number of folds and validation blocks")
             # Return train part by ids
             train_features, train_target = _ts_data_by_index(train_ids, train_ids, input_data)
             train_data = InputData(idx=np.arange(0, len(train_target)),
@@ -156,4 +159,8 @@ def _ts_data_by_index(train_ids, test_ids, data):
     features = data.features[train_ids]
     target = data.target[test_ids]
 
+    # Use only the first time-series as target for multi_ts
+    if data.data_type == DataTypesEnum.multi_ts:
+        target = target[:, 0]
+
     return features, target
