@@ -10,6 +10,7 @@ from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.pipelines.verification import verifier_for_task
 from fedot.core.repository.dataset_types import DataTypesEnum
 from fedot.core.repository.tasks import TaskTypesEnum
+from fedot.core.utilities.random import RandomStateHandler
 from fedot.remote.pipeline_run_config import PipelineRunConfig
 
 
@@ -64,6 +65,7 @@ def fit_pipeline(config_file: Union[str, bytes]) -> bool:
         return False
 
     try:
+        RandomStateHandler.MODEL_FITTING_SEED = 0
         pipeline.fit_from_scratch(train_data)
     except Exception as ex:
         logger.error(ex)
@@ -73,7 +75,8 @@ def fit_pipeline(config_file: Union[str, bytes]) -> bool:
         test_data = InputData.from_csv(config.test_data_path)
         pipeline.predict(test_data)
 
-    pipeline.save(path=os.path.join(config.output_path, 'fitted_pipeline'), datetime_in_path=False)
+    pipeline.save(path=os.path.join(config.output_path, 'fitted_pipeline'), create_subdir=False,
+                  is_datetime_in_path=False)
 
     return True
 
